Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Args ¶
type Args struct {
// All lists of all arguments in command line (not including the command itself)
All []string
// Completed lists of all completed arguments in command line,
// If the last one is still being typed - no space after it,
// it won't appear in this list of arguments.
Completed []string
// Last argument in command line, the one being typed, if the last
// character in the command line is a space, this argument will be empty,
// otherwise this would be the last word.
Last string
// LastCompleted is the last argument that was fully typed.
// If the last character in the command line is space, this would be the
// last word, otherwise, it would be the word before that.
LastCompleted string
// ParsedRoot is the return value of [Parser.Parse], and should be the root command
// structure for your CLI framework.
//
// It's useful for a more complex, dynamic [Predictor]. For example, returning
// different options depending on another flag value or positional argument.
//
// Always 'nil' when no Parser is provided.
ParsedRoot any
}
Args describes command line arguments
Click to show internal directories.
Click to hide internal directories.