Documentation
¶
Index ¶
Constants ¶
const TabMarker = "<TAB>"
TabMarker can be placed in the prompt to show where the hypothetical user pressed TAB
Variables ¶
This section is empty.
Functions ¶
func Assert ¶
Assert that the parser returns the correct suggestions given the prompt
See the docs for Suggestions on how the prompt should look
func Suggestions ¶
Suggestions returns the options returned by the parser with a given prompt
The prompt should look like it would on the command-line. If '<TAB>' is included, that is where we will assume the user pressed the tab key. The end of the prompt is used otherwise.
Example: "mycli sub --<TAB> --other"
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.